use sea_orm_migration::prelude::*;

pub struct Migration;

impl MigrationName for Migration {
    fn name(&self) -> &str {
        "m20220907_223615_create_users"
    }
}

#[async_trait::async_trait]
impl MigrationTrait for Migration {
    async fn up(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .create_table(
                Table::create()
                    .table(User::Table)
                    .if_not_exists()
                    .col(ColumnDef::new(User::Id)
                        .string()
                        .not_null()
                        .primary_key()
                    )
                    .col(ColumnDef::new(User::Name)
                        .string()
                        .not_null()
                    )
                    .col(ColumnDef::new(User::Email)
                        .string()
                        .not_null()
                        .unique_key()
                    )
                    .col(ColumnDef::new(User::Password)
                        .string()
                        .not_null()
                    )
                    .col(ColumnDef::new(User::Active)
                        .boolean()
                        .not_null()
                        .default(true)
                    )
                    .col(ColumnDef::new(User::Admin)
                        .boolean()
                        .not_null()
                        .default(false)
                    )
                    .to_owned(),
            )
            .await
    }

    async fn down(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .drop_table(Table::drop().table(User::Table).to_owned())
            .await
    }
}

/// Learn more at https://docs.rs/sea-query#iden
#[derive(Iden)]
pub enum User {
    Table,
    Id,
    Name,
    Email,
    Password,
    Active,
    Admin
}
